# Generated by Django 2.2.28 on 2022-04-15 14:52

import django.contrib.postgres.indexes
from django.contrib.postgres.operations import (
    BtreeGinExtension,
    TrigramExtension,
)
from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0011_auto_20220323_1022'),
    ]

    operations = [
        TrigramExtension(),
        BtreeGinExtension(),
        migrations.AddField(
            model_name='admhierarchy',
            name='name_with_parents',
            field=models.CharField(blank=True, max_length=500, null=True, verbose_name='Полное наименование'),
        ),
        migrations.AddField(
            model_name='munhierarchy',
            name='name_with_parents',
            field=models.CharField(blank=True, max_length=500, null=True, verbose_name='Полное наименование'),
        ),
        migrations.AddIndex(
            model_name='admhierarchy',
            index=django.contrib.postgres.indexes.GinIndex(fields=['name_with_parents'], name='m3_gar_admh_name_wi_5f5f5a_gin'),
        ),
        migrations.AddIndex(
            model_name='munhierarchy',
            index=django.contrib.postgres.indexes.GinIndex(fields=['name_with_parents'], name='m3_gar_munh_name_wi_380974_gin'),
        ),
    ]
