# Generated by Django 3.2.25 on 2024-03-29 15:39

import django.contrib.postgres.indexes
from django.db import (
    migrations,
)


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0016_alter_normativedocs_orgname'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='apartments',
            index=django.contrib.postgres.indexes.HashIndex(fields=['objectguid'], name='m3_gar_apar_objectg_0e459a_hash'),
        ),
    ]
