# Generated by Django 3.2.25 on 2024-04-11 11:00

from django.db import (
    migrations,
)


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0020_update_version_status'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='version',
            name='processed',
        ),
    ]
