# Generated by Django 3.2.4 on 2022-03-23 10:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0010_auto_20220225_0934'),
    ]

    operations = [
        migrations.AlterField(
            model_name='admhierarchy',
            name='path',
            field=models.TextField(blank=True, null=True, verbose_name='Материализованный путь к объекту (полная иерархия)'),
        ),
        migrations.AlterField(
            model_name='munhierarchy',
            name='path',
            field=models.TextField(blank=True, null=True, verbose_name='Материализованный путь к объекту (полная иерархия)'),
        ),
    ]
