# Generated by Django 3.2.25 on 2024-03-29 19:29

from django.db import (
    migrations,
)

import m3_gar.models.indexes


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0017_apartments_m3_gar_apar_objectg_0e459a_hash'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='addrobj',
            index=m3_gar.models.indexes.UpperGinIndex(fastupdate=True, fields=['name_with_typename'], name='addrobj_name_with_typename_gin', opclasses=['gin_trgm_ops']),
        ),
    ]
