# Generated by Django 3.2.25 on 2024-04-10 08:50

from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0018_addrobj_addrobj_name_with_typename_gin'),
    ]

    operations = [
        migrations.AddField(
            model_name='version',
            name='status',
            field=models.CharField(choices=[('new', 'Новое'), ('skipped', 'Пропущено'), ('error', 'Ошибка'), ('finished', 'Завершено')], default='new', max_length=20, verbose_name='Статус обновления'),
        ),
    ]
